@@ -818,7 +818,7 @@ void imapParser::parseDelegate (parseString & result)
     rights.append( word );
   }
 
-  lastResults.append( email + ":" + rights.join( "," ) );
+  lastResults.append( email + ':' + rights.join( "," ) );
 }
 
 void imapParser::parseOutOfOffice (parseString & result)
@@ -829,7 +829,7 @@ void imapParser::parseOutOfOffice (parseString & result)
   int outlen = 1;
   TQCString msg = parseLiteralC (result, false, false, &outlen);
 
-  lastResults.append( state + "^" + TQString::fromUtf8( msg ) );
+  lastResults.append( state + '^' + TQString::fromUtf8( msg ) );
 }
 
 void imapParser::parseMyRights (parseString & result)
@@ -1259,7 +1259,7 @@ mimeHeader * imapParser::parseBodyStructure (parseString & inWords,
       localPart->setPartSpecifier(inSection);
     }
 
-    // is multipart (otherwise its a simplepart and handled later)
+    // is multipart (otherwise it is a simplepart and handled later)
     while (inWords[0] == '(')
     {
       outSection = TQString::number(++section);
